/*
 * Copyright 2012-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.boot.docs.springbootfeatures.sql.jooq;

import java.util.GregorianCalendar;
import java.util.List;

import org.jooq.DSLContext;

import org.springframework.stereotype.Component;

import static org.springframework.boot.docs.springbootfeatures.sql.jooq.Tables.AUTHOR;

@Component
public class JooqExample {

	private final DSLContext create;

	public JooqExample(DSLContext dslContext) {
		this.create = dslContext;
	}

	// tag::method[]
	public List<GregorianCalendar> authorsBornAfter1980() {
		// @formatter:off
		return this.create.selectFrom(AUTHOR)
				.where(AUTHOR.DATE_OF_BIRTH.greaterThan(new GregorianCalendar(1980, 0, 1)))
				.fetch(AUTHOR.DATE_OF_BIRTH);
		// @formatter:on
	} // end::method[]

}
